SystemOrganization addCategory: #'Zinc-Tests-Functional'!
SystemOrganization addCategory: #'Zinc-Tests-New'!

TestCase subclass: #ZnClientTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/7/2010 19:50'!
testGetJpeg
	| url result |
	url := 'http://caretaker.wolf359.be/sun-fire-x2100.jpg' asUrl.
	result := ZnClient getJpeg: url.
	self assert: (result isKindOf: Form)! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/7/2010 19:57'!
testGetSmallHTMLDocument
	| url response |
	url := 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html' asUrl.
	response := ZnClient get: url.
	self assert: (response headers contentType = ZnMimeType textHtml).
	self assert: (response statusLine code = 200).
	self assert: (response entity string includesSubString: 'small')! !

TestCase subclass: #ZnEntityTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnEntityTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/11/2010 14:19'!
testReading
	| contents entity |
	contents := 'This is a test'.
	entity := ZnEntity 
				readFrom: contents readStream 
				usingType: ZnMimeType textPlain 
				andLength: contents size.
	self assert: (entity isKindOf: ZnStringEntity).
	self assert: entity string = contents.
	self assert: entity contentLength = contents size.
	self assert: entity contentType = ZnMimeType textPlain ! !

!ZnEntityTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/12/2010 10:11'!
testWritingApplicationUrlEncoding
	| entity string |
	entity := ZnApplicationFormUrlEncodedEntity new.
	entity at: 'foo' put: 'bar'.
	string := String streamContents: [ :stream | entity writeOn: stream ].
	self assert: string = 'foo=bar'.
	self assert: entity contentLength = 7! !

TestCase subclass: #ZnHTTPMethodTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-Functional'!

!ZnHTTPMethodTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/1/2010 19:50'!
testGetSmallHTMLDocument
	| doc url |
	url := 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html' asUrl.
	doc := ZnHTTPSocketFacade httpGet: url.
	self assert: (doc mimeType = MIMEType defaultHTML).
	self assert: (doc uri = url).
	self assert: (doc contents includesSubString: 'small')! !

TestCase subclass: #ZnHTTPSocketFacadeTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnHTTPSocketFacadeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/14/2010 13:17'!
testGetSmallHTMLDocument
	| mimeDocument |
	mimeDocument := ZnHTTPSocketFacade httpGetDocument: 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html'.
	self assert: (mimeDocument contents includesSubString: 'small').
	self assert: (mimeDocument contentType includesSubString: 'text/html')! !

!ZnHTTPSocketFacadeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/14/2010 13:18'!
testGetSmallHTMLStream
	| stream |
	stream := ZnHTTPSocketFacade httpGet: 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html'.
	self assert: (stream contents includesSubString: 'small')! !

!ZnHTTPSocketFacadeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/14/2010 15:06'!
testPut
	| server result dataString |
	server := ZnServer on: 1701.
	server authenticator: [ :username :password | username = 'user' and: [ password = 'secret' ] ].
	dataString := String streamContents: [ :stream | 
		(1 to: 67) do: [ :each | stream nextPut: (Character digitValue: each \\ 9) ] ].
	[ 
		server start.
		result := ZnHTTPSocketFacade httpPut: dataString to: 'http://localhost:1701/echo/foo' user: 'user' passwd: 'secret'.
		self assert: (result beginsWith: 'HTTP/1.1 200 OK').
		self assert: (result includesSubString: 'length 67')
	]
		ensure: [ server stop ]! !

TestCase subclass: #ZnHeadersTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 20:59'!
testMergeValued
	| headers |
	headers := ZnHeaders new.
	headers at: 'Set-Cookie' put: 'foo=1'.
	headers at: 'Set-Cookie' put: 'bar=1' ifPresentMerge: [ :old :new | old, ';', new ].
	self assert: (headers at: 'Set-Cookie') = 'foo=1;bar=1'
	
	! !

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 20:57'!
testMultiValued
	| headers |
	headers := ZnHeaders new.
	headers at: 'Set-Cookie' put: 'foo=1'.
	headers at: 'Set-Cookie' add: 'bar=1'.
	self assert: (headers at: 'Set-Cookie') = #('foo=1' 'bar=1')
	
	! !

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 21:03'!
testMultiValuedStreaming
	| headers keysAndValues |
	headers := ZnHeaders new.
	headers at: 'Set-Cookie' put: 'foo=1'.
	headers at: 'Set-Cookie' add: 'bar=1'.
	keysAndValues := OrderedCollection streamContents: [ : stream |
		headers headersDo: [ :key :value |
			stream nextPut: key; nextPut: value ] ].
	self assert: keysAndValues  = #('Set-Cookie' 'foo=1' 'Set-Cookie' 'bar=1') asOrderedCollection 
	
	! !

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 20:55'!
testNormalization
	| headers |
	headers := ZnHeaders new.
	headers at: 'content-TYPE' put: 'text/plain'.
	self assert: (headers includesKey: 'content-type').
	self assert: (headers includesKey: 'content-TYPE').
	self assert: (headers at: 'Content-Type') = 'text/plain'.
	headers at: 'CONTENT-type' put: 'text/html'.
	self assert: (headers at: 'Content-Type') = 'text/html'.

	! !

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/6/2010 20:16'!
testReading
	| string headers |
	string := 'Content-Type: text/plain', String crlf, 'Content-Length: 128', String crlf.
	headers := ZnHeaders readFrom: string readStream.
	self assert: (headers includesKey: 'Content-Type').
	self assert: (headers includesKey: 'Content-Length').
	self assert: (headers at: 'Content-Type') = 'text/plain'.
	self assert: (headers at: 'Content-Length') = '128'.! !

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/6/2010 20:20'!
testWriting
	| headers string |
	headers := ZnHeaders new 
		at: 'Content-Type' put: 'text/plain'; 
		at: 'Content-Length' put: '128';
		yourself.
	string := String streamContents: [ :stream | headers writeOn: stream ].
	self assert: (string includesSubString: 'Content-Type: text/plain', String crlf).
	self assert: (string includesSubString: 'Content-Length: 128', String crlf).
	self assert: (string occurrencesOf: Character cr) = 2.
	self assert: (string occurrencesOf: Character lf) = 2! !

TestCase subclass: #ZnMimeTypeTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnMimeTypeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/15/2010 07:27'!
testReading
	| mimeType |
	mimeType := ZnMimeType fromString: 'text/plain; charset=utf-8'.
	self assert: (mimeType main = 'text').
	self assert: (mimeType sub = 'plain').
	self assert: (mimeType charSet = 'utf-8').
	self assert: mimeType isBinary not! !

!ZnMimeTypeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/15/2010 07:29'!
testWriting
	| mimeType |
	(mimeType := ZnMimeType main: 'text' sub: 'plain')
		charset: 'utf-8'.
	self assert: mimeType printString = 'text/plain;charset=utf-8'.
	self assert: mimeType isBinary not! !

TestCase subclass: #ZnRequestLineTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnRequestLineTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/15/2010 14:08'!
testReading
	| requestLine string |
	string := 'GET /foo/bar/xyz.txt HTTP/1.1', String crlf.
	requestLine := ZnRequestLine readFrom: string readStream.
	self assert: requestLine method = #GET.
	self assert: requestLine uriPathQueryFragment = '/foo/bar/xyz.txt'.
	self assert: requestLine version = ZnConstants defaultHTTPVersion ! !

!ZnRequestLineTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/15/2010 14:11'!
testWriting
	| requestLine string |
	requestLine := ZnRequestLine method: 'GET' uri: '/foo/bar/xyz.txt'.
	string := String streamContents: [ :stream | requestLine writeOn: stream ].
	self assert: string = ('GET /foo/bar/xyz.txt HTTP/1.1', String crlf)! !

TestCase subclass: #ZnRequestTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnRequestTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/12/2010 20:25'!
testBasicAuthenticate
	| request |
	request := ZnRequest new.
	request setBasicAuthenticationUsername: 'user' password: 'secret'.
	self assert: (request headers at: 'Authorization') = 'Basic dXNlcjpzZWNyZXQ='! !

TestCase subclass: #ZnServerTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/13/2010 13:08'!
testAuthorizationFailed
	| server response |
	server := ZnServer on: 1701.
	server authenticator: [ :username :password | username = 'foo' and: [ password = 'secret' ] ].
	[ 
		server start.
		response := ZnClient get: 'http://localhost:1701/echo/foo'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 401).
		self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Basic').
		self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Zinc')
	]
		ensure: [ server stop ]! !

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/13/2010 13:06'!
testAuthorizationSuccessful
	| server response |
	server := ZnServer on: 1701.
	server authenticator: [ :username :password | username = 'foo' and: [ password = 'secret' ] ].
	[ 
		server start.
		response := ZnClient get: 'http://localhost:1701/echo/foo' username: 'foo' password: 'secret'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubString: 'Zinc').
		self assert: (response entity string includesSubString: 'foo')
	]
		ensure: [ server stop ]! !

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/15/2010 09:38'!
testEcho
	| server response |
	server := ZnServer on: 1701.
	[ 
		server start.
		response := ZnClient get: 'http://localhost:1701/echo/foo'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubString: 'Zinc').
		self assert: (response entity string includesSubString: 'foo')
	]
		ensure: [ server stop ]! !

TestCase subclass: #ZnStatusLineTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnStatusLineTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/15/2010 14:09'!
testReading
	| statusLine string |
	string := 'HTTP/1.1 200 OK', String crlf.
	statusLine := ZnStatusLine readFrom: string readStream.
	self assert: statusLine code = 200.
	self assert: statusLine reason = 'OK'.
	self assert: statusLine version = ZnConstants defaultHTTPVersion ! !

!ZnStatusLineTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/15/2010 14:11'!
testWriting
	| statusLine string |
	statusLine := ZnStatusLine code: 200.
	string := String streamContents: [ :stream | statusLine writeOn: stream ].
	self assert: string = ('HTTP/1.1 200 OK', String crlf)! !

TestCase subclass: #ZnUtilsTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests-New'!

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 20:09'!
testCapitalizeString
	self assert: (ZnUtils capitalizeString: 'content-type') = 'Content-Type'.
	self assert: (ZnUtils capitalizeString: 'CONTENT-type') = 'Content-Type'.
	self assert: (ZnUtils capitalizeString: 'content-TYPE') = 'Content-Type'.
	self assert: (ZnUtils capitalizeString: 'WWW-Authenticate') = 'Www-Authenticate'.
	self assert: (ZnUtils capitalizeString: 'Content-MD5') = 'Content-Md5'.! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 20:10'!
testIsCapitalizedString
	self assert: (ZnUtils isCapitalizedString: 'Content-Type').
	self assert: (ZnUtils isCapitalizedString: 'CONTENT-type') not.
	self assert: (ZnUtils isCapitalizedString: 'content-TYPE') not.
	self assert: (ZnUtils isCapitalizedString: 'WWW-Authenticate') not.
	self assert: (ZnUtils isCapitalizedString: 'Connection')! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/11/2010 21:36'!
testQueryParsing
	| string fields |
	string := 'foo=100&x=', ('/a b' encodeForHTTP).
	fields := ZnUtils parseQueryFrom: string readStream.
	self assert: (fields at: 'foo') = '100'.
	self assert: (fields at: 'x') = '/a b'.
	! !
